
bind PotMeter <Any-Enter> {
	focus -force %W
}

set color grey85

proc addPotMeter { frame name text format } {
	global color

	frame $frame -bg $color

	set size 48

	if { $format == "small" } {
		set size 32
	}
	if { $format == "medium" } {
		set size 44
	}
	if { $format == "large" } {
		set size 60
	}

	potmeter $frame.pot -variable $name -start 128 -bg $color -style amp \
		-size $size -command "setChambre $name" -shadow 7 -fg gold \
		-pothighcolor white -potpointcolor black -potmaincolor red -from 1 \
		-potlowcolor grey70
	label $frame.label -text $text -relief flat -width 10 -bg $color
	if { $format == "small" } {
		$frame.label configure -font 5x8
	}
	pack $frame.pot -side top
	pack $frame.label -side top -expand y -fill y

	pack $frame -side left -expand y -fill y
}

proc buildPanel { frame } {
	frame $frame.early -relief raised -bd 1
	label $frame.early.lab -text "Early Reflections"
	frame $frame.early.controls -relief raised -bd 1
	frame $frame.early.controls.main
	frame $frame.early.controls.delays
	frame $frame.late -relief raised -bd 1
	label $frame.late.lab -text "Late Reflections"
	frame $frame.late.controls -relief raised -bd 1
	frame $frame.late.controls.main
	frame $frame.late.controls.delays

	addPotMeter $frame.early.controls.main.el eLev "Level" medium
	addPotMeter $frame.early.controls.main.ed eDamp "Damping" medium
	addPotMeter $frame.early.controls.main.ef eFeed "Feedback" medium

	addPotMeter $frame.early.controls.main.elim eLim "Cutoff" meduim
#	addPotMeter $frame.early.controls.main.egain eGain "Gain" small

	addPotMeter $frame.early.controls.delays.er eRef "Delay" small
	addPotMeter $frame.early.controls.delays.e1 eD1 "Reflect1" small
	addPotMeter $frame.early.controls.delays.e2 eD2 "Reflect2" small
	addPotMeter $frame.early.controls.delays.e3 eD3 "Reflect3" small
	addPotMeter $frame.early.controls.delays.e4 eD4 "Reflect4" small

	addPotMeter $frame.late.controls.main.ll lLev "Level" medium
	addPotMeter $frame.late.controls.main.ld lDamp "Damping" medium
	addPotMeter $frame.late.controls.main.lf lFeed "Feedback" medium

	addPotMeter $frame.late.controls.main.llim lLim "Cutoff" meduim
#	addPotMeter $frame.late.controls.main.lgain lGain "Gain" small

	addPotMeter $frame.late.controls.delays.lr lRef "Delay" small
	addPotMeter $frame.late.controls.delays.l1 lD1 "Reflect1" small
	addPotMeter $frame.late.controls.delays.l2 lD2 "Reflect2" small
	addPotMeter $frame.late.controls.delays.l3 lD3 "Reflect3" small
	addPotMeter $frame.late.controls.delays.l4 lD4 "Reflect4" small

	pack $frame.early.lab $frame.early.controls -side top
	pack $frame.early.controls.main $frame.early.controls.delays -side top

	pack $frame.late.lab $frame.late.controls -side top
	pack $frame.late.controls.main $frame.late.controls.delays -side top

	pack $frame.early $frame.late -side left
}

proc buildChambre {} {
	global color

	button .base -width 680 -height 150 -bg black -fg black
	bindtags .base {SLabLogo 2 3 4}

	frame .base.controls -relief raised -bd 3 -bg $color
	frame .base.controls.t -bg $color
	label .base.controls.t.text -relief flat -fg black -bg $color -justify left\
		-text "      Chambre Reverb" -width 20 \
		-font "-*-lucida-*-r-*-sans-*-300-*-*-*-*-*-*"
	frame .base.controls.c -bg $color

	buildPanel .base.controls.c

	pack .base.controls.t.text -side left -anchor w
	pack .base.controls.t -side top -expand y -fill x -anchor w
	pack .base.controls.c -side top -anchor w -padx 10 -expand y -fill both
	pack .base.controls -side top -anchor w -padx 10 -expand y -fill both
	pack .base -ipadx 10 -ipady 10 -expand y -fill both

	wm title . "Chambre Reverb"
}

proc buildMemories {} {
	global memoryFileName

	#
	# Want to get some values from a config file, if possible.
	#
	set memoryFileName [setChambre getfilename].chambre

	menu .base.controls.mem
	.base.controls.mem add cascade -menu .base.controls.mem.load -label "Load"
	.base.controls.mem add cascade -menu .base.controls.mem.save -label "Save"
	menu .base.controls.mem.load
	.base.controls.mem.load add command -label "Memory 0" -command \
		"setChambre memget $memoryFileName 0"
	.base.controls.mem.load add command -label "Memory 1" -command \
		"setChambre memget $memoryFileName 1"
	.base.controls.mem.load add command -label "Memory 2" -command \
		"setChambre memget $memoryFileName 2"
	.base.controls.mem.load add command -label "Memory 3" -command \
		"setChambre memget $memoryFileName 3"
	menu .base.controls.mem.save
	.base.controls.mem.save add command -label "Memory 0" -command \
		"setChambre memset $memoryFileName 0"
	.base.controls.mem.save add command -label "Memory 1" -command \
		"setChambre memset $memoryFileName 1"
	.base.controls.mem.save add command -label "Memory 2" -command \
		"setChambre memset $memoryFileName 2"
	.base.controls.mem.save add command -label "Memory 3" -command \
		"setChambre memset $memoryFileName 3"

	bind .base.controls <Button-3> {
		catch {tk_popup .base.controls.mem %X %Y}
	}
	bind .base <Button-3> {
		catch {tk_popup .base.controls.mem %X %Y}
	}
	bind . <Button-3> {
		catch {tk_popup .base.controls.mem %X %Y}
	}

	#
	# Load the first file is possible
	#
	catch {setChambre memget $memoryFileName 0}
}

buildChambre
buildMemories

